summaryrefslogtreecommitdiffstats
path: root/chrome/browser/plugin_download_helper.h
diff options
context:
space:
mode:
authortfarina@chromium.org <tfarina@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-11-30 21:34:02 +0000
committertfarina@chromium.org <tfarina@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-11-30 21:34:02 +0000
commit6981d96328621a75557dbf843c5aab83bf4f55a3 (patch)
tree8a95daea7aad9b8bce1ced62fda4068ed296125a /chrome/browser/plugin_download_helper.h
parentd4e04a67c7f529bc8137c2dc5618e5a8c2123a13 (diff)
downloadchromium_src-6981d96328621a75557dbf843c5aab83bf4f55a3.zip
chromium_src-6981d96328621a75557dbf843c5aab83bf4f55a3.tar.gz
chromium_src-6981d96328621a75557dbf843c5aab83bf4f55a3.tar.bz2
net: Remove typedef net::URLRequest URLRequest;
BUG=64263 TEST=compiled locally, trybots Review URL: http://codereview.chromium.org/5384002 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@67762 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/plugin_download_helper.h')
-rw-r--r--chrome/browser/plugin_download_helper.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/chrome/browser/plugin_download_helper.h b/chrome/browser/plugin_download_helper.h
index 5d1a243..cccf3f0 100644
--- a/chrome/browser/plugin_download_helper.h
+++ b/chrome/browser/plugin_download_helper.h
@@ -18,7 +18,7 @@
// The PluginDownloadUrlHelper is used to handle one download URL request
// from the plugin. Each download request is handled by a new instance
// of this class.
-class PluginDownloadUrlHelper : public URLRequest::Delegate {
+class PluginDownloadUrlHelper : public net::URLRequest::Delegate {
static const int kDownloadFileBufferSize = 32768;
public:
// The delegate receives notification about the status of downloads
@@ -38,27 +38,27 @@ class PluginDownloadUrlHelper : public URLRequest::Delegate {
void InitiateDownload(URLRequestContext* request_context);
- // URLRequest::Delegate
- virtual void OnAuthRequired(URLRequest* request,
+ // net::URLRequest::Delegate
+ virtual void OnAuthRequired(net::URLRequest* request,
net::AuthChallengeInfo* auth_info);
- virtual void OnSSLCertificateError(URLRequest* request,
+ virtual void OnSSLCertificateError(net::URLRequest* request,
int cert_error,
net::X509Certificate* cert);
- virtual void OnResponseStarted(URLRequest* request);
- virtual void OnReadCompleted(URLRequest* request, int bytes_read);
+ virtual void OnResponseStarted(net::URLRequest* request);
+ virtual void OnReadCompleted(net::URLRequest* request, int bytes_read);
- void OnDownloadCompleted(URLRequest* request);
+ void OnDownloadCompleted(net::URLRequest* request);
protected:
void DownloadCompletedHelper(bool success);
// The download file request initiated by the plugin.
- URLRequest* download_file_request_;
+ net::URLRequest* download_file_request_;
// Handle to the downloaded file.
scoped_ptr<net::FileStream> download_file_;
// The full path of the downloaded file.
FilePath download_file_path_;
// The buffer passed off to URLRequest::Read.
scoped_refptr<net::IOBuffer> download_file_buffer_;
// TODO(port): this comment doesn't describe the situation on Posix.
// The window handle for sending the WM_COPYDATA notification,
@@ -38,27 +38,27 @@ class PluginDownloadUrlHelper : public URLRequest::Delegate {
// The full path of the downloaded file.
FilePath download_file_path_;
- // The buffer passed off to URLRequest::Read.
+ // The buffer passed off to net::URLRequest::Read.
scoped_refptr<net::IOBuffer> download_file_buffer_;
// TODO(port): this comment doesn't describe the situation on Posix.